]> git.eshelyaron.com Git - emacs.git/commitdiff
xml.c: Rework the functions to take regions instead of strings,
authorLars Magne Ingebrigtsen <larsi@gnus.org>
Sat, 2 Oct 2010 00:36:47 +0000 (02:36 +0200)
committerLars Magne Ingebrigtsen <larsi@gnus.org>
Sat, 2 Oct 2010 00:36:47 +0000 (02:36 +0200)
and rename the functions to reflect clearly that they come from the
libxml package.

src/ChangeLog
src/xml.c

index e10a6a43dfdd98b6fa553eec6088b73621749982..70a7d43c32066977ff29e8500ce879d1e7612f17 100644 (file)
@@ -1,3 +1,9 @@
+2010-10-02  Lars Magne Ingebrigtsen  <larsi@gnus.org>
+
+       * xml.c (Flibxml_parse_xml_region, Flibxml_parse_html_region)
+       (parse_region): Reworked to take regions instead of strings, and
+       renamed to reflect that these are the libxml functions.
+
 2010-10-01  Eli Zaretskii  <eliz@gnu.org>
 
        * term.c (init_tty) [DOS_NT]: Don't call Wcm_clear after setting
index 6f4b1e79cd4126be971e2008e953535438e965c4..a3919db4ecdd79d97d999a9beb30390e857f4e01 100644 (file)
--- a/src/xml.c
+++ b/src/xml.c
@@ -74,17 +74,24 @@ Lisp_Object make_dom (xmlNode *node)
 }
 
 static Lisp_Object
-parse_string (Lisp_Object string, Lisp_Object base_url, int htmlp)
+parse_region (Lisp_Object start, Lisp_Object end, Lisp_Object base_url, int htmlp)
 {
   xmlDoc *doc;
   xmlNode *node;
   Lisp_Object result = Qnil;
-  int ibeg, iend;
   const char *burl = "";
+  EMACS_INT bytes;
+  EMACS_INT istart, iend;
 
   LIBXML_TEST_VERSION;
 
-  CHECK_STRING (string);
+  validate_region (&start, &end);
+  
+  istart = XINT (start);
+  iend = XINT (end);
+
+  if (istart < GPT && GPT < iend)
+    move_gap (iend);
 
   if (! NILP (base_url))
     {
@@ -92,13 +99,18 @@ parse_string (Lisp_Object string, Lisp_Object base_url, int htmlp)
       burl = SDATA (base_url);
     }
 
-  doc = htmlp
-    ? htmlReadMemory (SDATA (string), SBYTES (string), burl, "utf-8",
-                     HTML_PARSE_RECOVER|HTML_PARSE_NONET|
-                     HTML_PARSE_NOWARNING|HTML_PARSE_NOERROR)
-    : xmlReadMemory (SDATA (string), SBYTES (string), burl, "utf-8",
-                    XML_PARSE_NONET|XML_PARSE_NOWARNING|
-                    XML_PARSE_NOERROR);
+  bytes = CHAR_TO_BYTE (iend) - CHAR_TO_BYTE (istart);
+  
+  if (htmlp)
+    doc = htmlReadMemory (BYTE_POS_ADDR (CHAR_TO_BYTE (istart)),
+                         bytes, burl, "utf-8",
+                         HTML_PARSE_RECOVER|HTML_PARSE_NONET|
+                         HTML_PARSE_NOWARNING|HTML_PARSE_NOERROR);
+  else
+    doc = xmlReadMemory (BYTE_POS_ADDR (CHAR_TO_BYTE (istart)),
+                        bytes, burl, "utf-8",
+                        XML_PARSE_NONET|XML_PARSE_NOWARNING|
+                        XML_PARSE_NOERROR);
 
   if (doc != NULL)
     {
@@ -112,24 +124,24 @@ parse_string (Lisp_Object string, Lisp_Object base_url, int htmlp)
   return result;
 }
 
-DEFUN ("xml-parse-html-string-internal", Fxml_parse_html_string_internal,
-       Sxml_parse_html_string_internal,
-       1, 2, 0,
-       doc: /* Parse STRING as an HTML document and return the parse tree.
+DEFUN ("libxml-parse-html-region", Flibxml_parse_html_region,
+       Slibxml_parse_html_region,
+       2, 3, 0,
+       doc: /* Parse the region as an HTML document and return the parse tree.
 If BASE-URL is non-nil, it is used to expand relative URLs.  */)
-  (Lisp_Object string, Lisp_Object base_url)
+  (Lisp_Object start, Lisp_Object end, Lisp_Object base_url)
 {
-  return parse_string (string, base_url, 1);
+  return parse_region (start, end, base_url, 1);
 }
 
-DEFUN ("xml-parse-string-internal", Fxml_parse_string_internal,
-       Sxml_parse_string_internal,
-       1, 2, 0,
-       doc: /* Parse STRING as an XML document and return the parse tree.
+DEFUN ("libxml-parse-xml-region", Flibxml_parse_xml_region,
+       Slibxml_parse_xml_region,
+       2, 3, 0,
+       doc: /* Parse the region as an XML document and return the parse tree.
 If BASE-URL is non-nil, it is used to expand relative URLs.  */)
-  (Lisp_Object string, Lisp_Object base_url)
+  (Lisp_Object start, Lisp_Object end, Lisp_Object base_url)
 {
-  return parse_string (string, base_url, 0);
+  return parse_region (start, end, base_url, 0);
 }
 
 \f
@@ -139,8 +151,8 @@ If BASE-URL is non-nil, it is used to expand relative URLs.  */)
 void
 syms_of_xml (void)
 {
-  defsubr (&Sxml_parse_html_string_internal);
-  defsubr (&Sxml_parse_string_internal);
+  defsubr (&Slibxml_parse_html_region);
+  defsubr (&Slibxml_parse_xml_region);
 }
 
 #endif /* HAVE_LIBXML2 */